from company_name_matching.matching_function import DefaultMatching